﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.AI;

[RequireComponent (typeof (NavMeshAgent))]
public class PlayerController : MonoBehaviour {

	public enum ControllType
	{
		Mouse,
		Key,
	}

	[SerializeField]
	ControllType		ControllerType = ControllType.Mouse;



	[SerializeField]
	float	Speed = 5f;

	[SerializeField]
	float	AngularSpeed = 180f;


	// NavMeshAgentをスクリプトから利用するための変数
	NavMeshAgent	m_navMeshAgent;

	Vector3			m_navTargetPos = Vector3.zero;


	// アニメーター
	Animator		m_animator;


	// Use this for initialization
	void Start () {
		// NavMeshAgentコンポーネントを取得
		m_navMeshAgent = GetComponent<NavMeshAgent> ();

		// Animatorコンポーネントを取得
		m_animator = GetComponent<Animator> ();
	}

	// Update is called once per frame
	void Update () {

		if (ControllerType == ControllType.Mouse)
		{

			// クリックした位置に移動
			if (Input.GetMouseButtonDown (0))
			{
				Ray ray = Camera.main.ScreenPointToRay (Input.mousePosition);
				RaycastHit hit = new RaycastHit ();

				if (Physics.Raycast (ray, out hit))
				{
					m_navTargetPos = hit.point;

					// NavMeshが準備できているなら
					if (m_navMeshAgent.pathStatus != NavMeshPathStatus.PathInvalid)
					{
						// NavMeshAgentに目的地をセット
						m_navMeshAgent.SetDestination (m_navTargetPos);
					}
				}
			}
		}

		if (ControllerType == ControllType.Key)
		{

			// 前後移動
			if (Input.GetKey (KeyCode.UpArrow))
			{
				transform.position += transform.forward * Speed * Time.deltaTime;
			} else if (Input.GetKey (KeyCode.DownArrow))
			{
				transform.position -= transform.forward * Speed * Time.deltaTime;
			}


			// 左右旋回
			Vector3 rot = transform.rotation.eulerAngles;
			if (Input.GetKey (KeyCode.LeftArrow))
			{
				rot.y -= AngularSpeed * Time.deltaTime;
			} else if (Input.GetKey (KeyCode.RightArrow))
			{
				rot.y += AngularSpeed * Time.deltaTime;
			}

			transform.rotation = Quaternion.Euler (rot);
		}


		m_animator.SetFloat ("SPEED", m_navMeshAgent.velocity.magnitude);
	}

	public float GetStrength()
	{
		return 0;
	}
}